@@ -9,7 +9,6 @@ import yaml
 
 import webviz_config.plugins
 from .utils import terminal_colors
-from .utils._get_webviz_plugins import _get_webviz_plugins
 from . import _deprecation_store as _ds
 
 SPECIAL_ARGS = ["self", "app", "webviz_settings", "_call_signature"]
@@ -116,18 +115,20 @@ def _call_signature(
                         "to see documentation of the plugin."
                         f"{terminal_colors.END}"
                     )
-            # Typechecking typing classes does not work in python 3.7
+            # We currently do not support subscriptable types, e.g. Optional[], List[], Dict[] etc.
+            # This will be supported after https://github.com/equinor/webviz-config/issues/199
             except TypeError:
                 pass
 
     kwargs_including_defaults = kwargs
-    deprecation_warnings = []
+    plugin_deprecation_warnings = []
+    argument_deprecation_warnings = []
 
     deprecated_plugin = _ds.DEPRECATION_STORE.get_stored_plugin_deprecation(
         getattr(webviz_config.plugins, plugin_name)
     )
     if deprecated_plugin:
-        deprecation_warnings.append(deprecated_plugin.short_message)
+        plugin_deprecation_warnings.append(deprecated_plugin.short_message)
         warnings.warn(
             f"""Plugin '{plugin_name}' has been deprecated.
 ------------------------
@@ -150,20 +151,15 @@ def _call_signature(
     for deprecation in deprecations:
         if isinstance(deprecation, _ds.DeprecatedArgument):
             if deprecation.argument_name in kwargs_including_defaults.keys():
-                deprecation_warnings.append(deprecation.short_message)
+                argument_deprecation_warnings.append(deprecation.short_message)
                 warnings.warn(
-                    """Deprecated Argument: '{}' with value '{}' in plugin '{}'
-------------------------
-{}
-===
-{}
-""".format(
-                        deprecation.argument_name,
-                        kwargs_including_defaults[deprecation.argument_name],
-                        plugin_name,
-                        deprecation.short_message,
-                        deprecation.long_message,
-                    ),
+                    f"Deprecated Argument: '{deprecation.argument_name}' with value "
+                    f"'{kwargs_including_defaults[deprecation.argument_name]}' "
+                    f"in plugin '{plugin_name}\n'"
+                    "------------------------\n"
+                    f"{deprecation.short_message}\n"
+                    "===\n"
+                    f"{deprecation.long_message}",
                     FutureWarning,
                 )
         elif isinstance(deprecation, _ds.DeprecatedArgumentCheck):
@@ -174,26 +170,21 @@ def _call_signature(
                         mapped_args[arg] = value
                         break
 
-            result = deprecation.callback(**mapped_args)  # type: ignore
+            result = deprecation.callback(**mapped_args)
             if result:
-                deprecation_warnings.append(result[0])
+                argument_deprecation_warnings.append(result[0])
+                _values = [
+                    value
+                    for key, value in kwargs_including_defaults.items()
+                    if key in deprecation.argument_names
+                ]
                 warnings.warn(
-                    """Deprecated Argument(s): '{}' with value(s) '{}' in plugin '{}'
-------------------------
-{}
-===
-{}
-""".format(
-                        deprecation.argument_names,
-                        [
-                            value
-                            for key, value in kwargs_including_defaults.items()
-                            if key in deprecation.argument_names
-                        ],
-                        plugin_name,
-                        result[0],
-                        result[1],
-                    ),
+                    f"Deprecated Argument(s): '{deprecation.argument_names}' "
+                    f"with value(s) '{_values}' in plugin '{plugin_name}'\n"
+                    "------------------------\n"
+                    f"{result[0]}\n"
+                    "===\n"
+                    f"{result[1]}",
                     FutureWarning,
                 )
 
@@ -207,7 +198,8 @@ def _call_signature(
         f"{plugin_name}({special_args}**{kwargs})",
         (
             f"plugin_layout(contact_person={contact_person}"
-            f", deprecation_warnings={deprecation_warnings})"
+            f", plugin_deprecation_warnings={plugin_deprecation_warnings}"
+            f", argument_deprecation_warnings={argument_deprecation_warnings})"
         ),
     )
 
@@ -218,9 +210,7 @@ class ParserError(Exception):
 
 class ConfigParser:
 
-    STANDARD_PLUGINS = [
-        name for (name, _) in _get_webviz_plugins(webviz_config.plugins)
-    ]
+    INSTALLED_PLUGINS = webviz_config.plugins.__all__
 
     def __init__(self, yaml_file: pathlib.Path):
 
@@ -233,10 +223,12 @@ class ConfigParser:
                 f"There is something wrong in the configuration file {yaml_file}. "
             )
 
-            if hasattr(excep, "problem_mark"):
+            # Looking forward to only supporting Python 3.8+ and PEP572...
+            problem_mark = getattr(excep, "problem_mark", None)
+            if problem_mark is not None:
                 extra_info += (
                     "The typo is probably somewhere around "
-                    f"line {excep.problem_mark.line + 1}."
+                    f"line {problem_mark.line + 1}."
                 )
 
             raise type(excep)(
@@ -245,6 +237,7 @@ class ConfigParser:
             ).with_traceback(sys.exc_info()[2])
 
         self._config_folder = pathlib.Path(yaml_file).parent
+        self._page_titles: List[str] = []
         self._page_ids: List[str] = []
         self._assets: set = set()
         self._plugin_metadata: Dict[str, dict] = {}
@@ -290,7 +283,6 @@ class ConfigParser:
         return page_id
 
     def clean_configuration(self) -> None:
-        # pylint: disable=too-many-branches,too-many-statements
         """Various cleaning and checks of the raw configuration read
         from the user provided yaml configuration file.
         """
@@ -305,7 +297,7 @@ class ConfigParser:
         if "title" not in self.configuration:
             self.configuration["title"] = "Webviz - Powered by Dash"
 
-        if "pages" not in self.configuration:
+        if "pages" not in self.configuration and "layout" not in self.configuration:
             raise ParserError(
                 f"{terminal_colors.RED}{terminal_colors.BOLD}"
                 "The configuration file does not have "
@@ -313,7 +305,9 @@ class ConfigParser:
                 f"{terminal_colors.END}"
             )
 
-        if not isinstance(self.configuration["pages"], list):
+        if "pages" in self.configuration and not isinstance(
+            self.configuration["pages"], list
+        ):
             raise ParserError(
                 f"{terminal_colors.RED}{terminal_colors.BOLD}"
                 "The configuration input belonging to the "
@@ -321,65 +315,27 @@ class ConfigParser:
                 f"{terminal_colors.END}"
             )
 
-        for page_number, page in enumerate(self.configuration["pages"]):
+        if "pages" in self.configuration:
+            warnings.warn(
+                "The configuration keyword `pages` is going to be deprecated. "
+                "Consider using the new `layout` keyword instead.",
+                PendingDeprecationWarning,
+            )
 
-            if "title" not in page:
-                raise ParserError(
-                    f"{terminal_colors.RED}{terminal_colors.BOLD}"
-                    f"Page number {page_number + 1} does "
-                    "not have the title specified."
-                    f"{terminal_colors.END}"
-                )
+        if "layout" in self.configuration and not isinstance(
+            self.configuration["layout"], list
+        ):
+            raise ParserError(
+                f"{terminal_colors.RED}{terminal_colors.BOLD}"
+                "The configuration input belonging to the "
+                "`layout` keyword should be a list."
+                f"{terminal_colors.END}"
+            )
 
-            if "id" not in page:
-                page["id"] = self._generate_page_id(page["title"])
-            elif page["id"] in self._page_ids:
-                raise ParserError(
-                    f"{terminal_colors.RED}{terminal_colors.BOLD}"
-                    "You have more than one page "
-                    "with the same `id`."
-                    f"{terminal_colors.END}"
-                )
+        if "pageContents" not in self.configuration:
+            self.configuration["pageContents"] = []
 
-            self._page_ids.append(page["id"])
-
-            if "content" not in page:
-                page["content"] = []
-            elif not isinstance(page["content"], list):
-                raise ParserError(
-                    f"{terminal_colors.RED}{terminal_colors.BOLD}"
-                    "The content of page number "
-                    f"{page_number + 1} should be a list."
-                    f"{terminal_colors.END}"
-                )
-
-            plugins = [e for e in page["content"] if isinstance(e, dict)]
-
-            for plugin in plugins:
-                plugin_name = next(iter(plugin))
-                plugin_variables = next(iter(plugin.values()))
-                kwargs = {} if plugin_variables is None else {**plugin_variables}
-
-                if plugin_name not in ConfigParser.STANDARD_PLUGINS:
-                    raise ParserError(
-                        f"{terminal_colors.RED}{terminal_colors.BOLD}"
-                        "You have included a plugin with "
-                        f"name `{plugin_name}` in your "
-                        "configuration file. This is not a "
-                        "standard plugin."
-                        f"{terminal_colors.END}"
-                    )
-
-                plugin["_call_signature"] = _call_signature(
-                    plugin_name,
-                    kwargs,
-                    self._config_folder,
-                )
-
-                self._assets.update(getattr(webviz_config.plugins, plugin_name).ASSETS)
-                self._plugin_metadata[
-                    plugin_name
-                ] = webviz_config.plugins.PLUGIN_METADATA[plugin_name]
+        self._parse_navigation()
 
     @property
     def configuration(self) -> dict:
@@ -399,3 +355,230 @@ class ConfigParser:
         plugins included in the configuration file.
         """
         return self._plugin_metadata
+
+    def _recursively_parse_navigation_item(self, items: dict, level: int) -> list:
+        navigation_items: list = []
+        for item_number, item in enumerate(items):
+            if "section" in item:
+                if level > 0:
+                    raise ParserError(
+                        f"{terminal_colors.RED}{terminal_colors.BOLD}"
+                        "Sections can only be defined on the first level"
+                        f"{terminal_colors.END}"
+                    )
+                navigation_items.append(
+                    {
+                        "type": "section",
+                        "title": item["section"],
+                        "icon": item["icon"] if "icon" in item.keys() else None,
+                        "content": self._recursively_parse_navigation_item(
+                            item["content"], level + 1
+                        )
+                        if "content" in item.keys()
+                        else [],
+                    }
+                )
+            elif "group" in item:
+                navigation_items.append(
+                    {
+                        "type": "group",
+                        "title": item["group"],
+                        "icon": item["icon"] if "icon" in item.keys() else None,
+                        "content": self._recursively_parse_navigation_item(
+                            item["content"], level + 1
+                        )
+                        if "content" in item.keys()
+                        else [],
+                    }
+                )
+            elif "page" in item or "title" in item:
+                page_title = item["page"] if "page" in item else item["title"]
+                self._page_titles.append(page_title)
+                if "id" not in item:
+                    item["id"] = self._generate_page_id(page_title)
+                elif item["id"] in self._page_ids:
+                    raise ParserError(
+                        f"{terminal_colors.RED}{terminal_colors.BOLD}"
+                        "You have more than one page "
+                        "with the same `id`."
+                        f"{terminal_colors.END}"
+                    )
+
+                self._page_ids.append(item["id"])
+
+                if "content" not in item:
+                    item["content"] = []
+                elif not isinstance(item["content"], list):
+                    raise ParserError(
+                        f"{terminal_colors.RED}{terminal_colors.BOLD}"
+                        "The content of page number "
+                        f"{item_number + 1} should be a list."
+                        f"{terminal_colors.END}"
+                    )
+
+                self.configuration["pageContents"].append(item)
+
+                navigation_items.append(
+                    {
+                        "type": "page",
+                        "title": page_title,
+                        "href": "/" + item["id"],
+                        "icon": item["icon"] if "icon" in item.keys() else None,
+                    }
+                )
+
+                plugins = [e for e in item["content"] if isinstance(e, dict)]
+                for plugin in plugins:
+                    plugin_name = next(iter(plugin))
+                    plugin_variables = next(iter(plugin.values()))
+                    kwargs = {} if plugin_variables is None else {**plugin_variables}
+
+                    if plugin_name not in ConfigParser.INSTALLED_PLUGINS:
+                        raise ParserError(
+                            f"{terminal_colors.RED}{terminal_colors.BOLD}"
+                            "You have included a plugin with "
+                            f"name `{plugin_name}` in your "
+                            "configuration file. This is not an "
+                            "installed plugin."
+                            f"{terminal_colors.END}"
+                        )
+
+                    plugin["_call_signature"] = _call_signature(
+                        plugin_name,
+                        kwargs,
+                        self._config_folder,
+                    )
+
+                    self._assets.update(
+                        getattr(webviz_config.plugins, plugin_name).ASSETS
+                    )
+                    self._plugin_metadata[
+                        plugin_name
+                    ] = webviz_config.plugins.PLUGIN_METADATA[plugin_name]
+        return navigation_items
+
+    def _parse_navigation(self) -> None:
+        # pylint: disable=too-many-branches
+        """Returns a list of navigation items"""
+
+        if "layout" in self.configuration:
+            self.configuration[
+                "navigation_items"
+            ] = self._recursively_parse_navigation_item(self.configuration["layout"], 0)
+        elif "pages" in self.configuration:
+            self.configuration[
+                "navigation_items"
+            ] = self._recursively_parse_navigation_item(self.configuration["pages"], 0)
+
+        self.configuration["options"] = self.configuration.get("options", {})
+        if "menu" in self.configuration["options"]:
+
+            if "bar_position" not in self.configuration["options"]["menu"]:
+                self.configuration["options"]["menu"]["bar_position"] = "left"
+            elif self.configuration["options"]["menu"]["bar_position"] not in [
+                "left",
+                "top",
+                "right",
+                "bottom",
+            ]:
+                raise ParserError(
+                    f"{terminal_colors.RED}{terminal_colors.BOLD}"
+                    "Invalid option for options > menu > bar_position: "
+                    f"{self.configuration['options']['menu']['bar_position']}. "
+                    "Please select one of the following options: left, top, right, bottom."
+                    f"{terminal_colors.END}"
+                )
+
+            if "drawer_position" not in self.configuration["options"]["menu"]:
+                self.configuration["options"]["menu"]["drawer_position"] = "left"
+            elif self.configuration["options"]["menu"]["drawer_position"] not in [
+                "left",
+                "right",
+            ]:
+                raise ParserError(
+                    f"{terminal_colors.RED}{terminal_colors.BOLD}"
+                    "Invalid option for options > menu > drawer_position: "
+                    f"{self.configuration['options']['menu']['drawer_position']}. "
+                    "Please select one of the following options: left, right."
+                    f"{terminal_colors.END}"
+                )
+
+            if "initially_pinned" not in self.configuration["options"]["menu"]:
+                self.configuration["options"]["menu"]["initially_pinned"] = False
+            elif not isinstance(
+                self.configuration["options"]["menu"]["initially_pinned"], bool
+            ):
+                raise ParserError(
+                    f"{terminal_colors.RED}{terminal_colors.BOLD}"
+                    "Invalid option for options > menu > initially_pinned: "
+                    f"{self.configuration['options']['menu']['initially_pinned']}. "
+                    "Please select a boolean value: True, False"
+                    f"{terminal_colors.END}"
+                )
+
+            if "homepage" not in self.configuration["options"]["menu"]:
+                self.configuration["options"]["menu"]["homepage"] = None
+            elif not isinstance(self.configuration["options"]["menu"]["homepage"], str):
+                raise ParserError(
+                    f"{terminal_colors.RED}{terminal_colors.BOLD}"
+                    "Invalid option for options > menu > homepage: "
+                    f"{self.configuration['options']['menu']['homepage']}. "
+                    "Please select a valid string value"
+                    f"{terminal_colors.END}"
+                )
+            elif (
+                self.configuration["options"]["menu"]["homepage"]
+                not in self._page_titles
+            ):
+                raise ParserError(
+                    f"{terminal_colors.RED}{terminal_colors.BOLD}"
+                    "Invalid option for options > menu > homepage: "
+                    f"{self.configuration['options']['menu']['homepage']}. "
+                    f"Please check your config file and use the name of an existing page."
+                    f"{terminal_colors.END}"
+                )
+            else:
+                self.configuration["options"]["menu"]["homepage"] = self._page_ids[
+                    self._page_titles.index(
+                        self.configuration["options"]["menu"]["homepage"]
+                    )
+                ]
+
+            if "initially_collapsed" not in self.configuration["options"]["menu"]:
+                self.configuration["options"]["menu"]["initially_collapsed"] = False
+            elif not isinstance(
+                self.configuration["options"]["menu"]["initially_collapsed"], bool
+            ):
+                raise ParserError(
+                    f"{terminal_colors.RED}{terminal_colors.BOLD}"
+                    "Invalid option for options > menu > initially_collapsed: "
+                    f"{self.configuration['options']['menu']['initially_collapsed']}. "
+                    "Please select a boolean value: True, False"
+                    f"{terminal_colors.END}"
+                )
+
+            if "show_logo" not in self.configuration["options"]["menu"]:
+                self.configuration["options"]["menu"]["show_logo"] = True
+            elif not isinstance(
+                self.configuration["options"]["menu"]["show_logo"], bool
+            ):
+                raise ParserError(
+                    f"{terminal_colors.RED}{terminal_colors.BOLD}"
+                    "Invalid option for options > menu > show_logo: "
+                    f"{self.configuration['options']['menu']['show_logo']}. "
+                    "Please select a boolean value: True, False"
+                    f"{terminal_colors.END}"
+                )
+        else:
+            self.configuration["options"]["menu"] = {
+                "bar_position": "left",
+                "drawer_position": "left",
+                "initially_pinned": False,
+                "initially_collapsed": False,
+                "show_logo": True,
+                "homepage": None,
+            }
+
+        self.configuration["options"]["plotly_theme"] = self.configuration[
+            "options"
+        ].get("plotly_theme", {})
