@@ -1,17 +1,16 @@
 import sys
 import json
+import shutil
+import logging
 import argparse
 import pathlib
+import subprocess
 
-from ._build_webviz import build_webviz
-from ._deployment import main_radix_deployment
-from ._docs.open_docs import open_docs
-from ._docs._create_schema import create_schema
 from ._user_data_dir import user_data_dir
 from ._user_preferences import set_user_preferences, get_user_preference
 
 
-def main() -> None:
+def main() -> None:  # pylint: disable=too-many-locals,too-many-statements
 
     parser = argparse.ArgumentParser(
         prog=("Creates a Webviz Dash app from a configuration setup")
@@ -19,13 +18,12 @@ def main() -> None:
 
     subparsers = parser.add_subparsers(
         metavar="SUBCOMMAND",
+        required=True,
         help="Below are the available subcommands listed. "
         "Type e.g. 'webviz build --help' "
         "to get help on one particular "
         "subcommand.",
     )
-    # When dropping Python 3.6 support, 'required' can be given as an argument to add_subparsers.
-    subparsers.required = True
 
     # Add "build" argument parser:
 
@@ -74,7 +72,14 @@ def main() -> None:
         help="Path to YAML file with logging configuration.",
     )
 
-    parser_build.set_defaults(func=build_webviz)
+    def parser_build_function(args: argparse.Namespace) -> None:
+        from ._build_webviz import (  # pylint: disable=import-outside-toplevel
+            build_webviz,
+        )
+
+        build_webviz(args)
+
+    parser_build.set_defaults(func=parser_build_function)
 
     # Add "certificate" parser:
 
@@ -108,15 +113,13 @@ def main() -> None:
 
     deployment_subparsers = parser_deploy.add_subparsers(
         metavar="DEPLOYMENT_METHOD",
+        required=True,
         help="Below are the available deployment subcommands listed. "
         "Type e.g. 'webviz deploy radix --help' "
         "to get help on one particular "
         "subcommand.",
     )
 
-    # When dropping Python 3.6 support, 'required' can be given as an argument to add_subparsers.
-    deployment_subparsers.required = True
-
     parser_radix_deploy = deployment_subparsers.add_parser(
         "radix",
         help="Deploy the app using Radix.",
@@ -141,7 +144,14 @@ def main() -> None:
         "Do not include this if only overwriting an existing application.",
     )
 
-    parser_radix_deploy.set_defaults(func=main_radix_deployment)
+    def parser_radix_deploy_function(args: argparse.Namespace) -> None:
+        from ._deployment import (  # pylint: disable=import-outside-toplevel
+            main_radix_deployment,
+        )
+
+        main_radix_deployment(args)
+
+    parser_radix_deploy.set_defaults(func=parser_radix_deploy_function)
 
     # Add "documentation" parser:
 
@@ -172,7 +182,14 @@ def main() -> None:
         help="Skip opening the documentation automatically in browser.",
     )
 
-    parser_docs.set_defaults(func=open_docs)
+    def parser_docs_function(args: argparse.Namespace) -> None:
+        from ._docs.open_docs import (  # pylint: disable=import-outside-toplevel
+            open_docs,
+        )
+
+        open_docs(args)
+
+    parser_docs.set_defaults(func=parser_docs_function)
 
     # Add "preferences" parser:
 
@@ -223,11 +240,55 @@ def main() -> None:
         "it will be stored in your Webviz application settings folder.",
     )
 
-    def entrypoint_schema(args: argparse.Namespace) -> None:
+    def parser_schema_function(args: argparse.Namespace) -> None:
+        from ._docs._create_schema import (  # pylint: disable=import-outside-toplevel
+            create_schema,
+        )
+
         args.output.write_text(json.dumps(create_schema(), indent=4))
         print(f"Schema written to {args.output}")
 
-    parser_schema.set_defaults(func=entrypoint_schema)
+    parser_schema.set_defaults(func=parser_schema_function)
+
+    # Add "editor" parser:
+
+    parser_editor = subparsers.add_parser(
+        "editor",
+        help="Create and edit Webviz configuration files",
+    )
+
+    # parser_editor.add_argument(
+    #     "--path",
+    #     type=pathlib.Path,
+    #     help="Path to already existing Webviz configuration file.",
+    # )
+
+    def entrypoint_editor(  # pylint: disable=unused-argument
+        args: argparse.Namespace,
+    ) -> None:
+
+        if sys.version_info < (3, 8):
+            raise RuntimeError("Webviz editor requires at least Python 3.8")
+
+        path_wce_executable = shutil.which("webviz-config-editor")
+        if path_wce_executable is None:
+            raise RuntimeError(
+                "webviz-config-editor executable not found. You can download this from "
+                "release assets (https://github.com/equinor/webviz-config-editor/releases)."
+            )
+
+        logging.warning(
+            "Note that Webviz editor is in beta and early testing. "
+            "Problems/bugs likely to occur."
+        )
+
+        command = [path_wce_executable]  # + ([] if args.path is None else [args.path])
+        try:
+            subprocess.run(command, check=True, capture_output=True)
+        except subprocess.CalledProcessError:
+            subprocess.run(command + ["--no-sandbox"], check=True)
+
+    parser_editor.set_defaults(func=entrypoint_editor)
 
     # Do the argument parsing:
 
