@@ -1,16 +1,9 @@
-try:
-    # Python 3.8+
-    from importlib.metadata import entry_points  # type: ignore
-except ModuleNotFoundError:
-    # Python < 3.8
-    from importlib_metadata import entry_points  # type: ignore
+from importlib.metadata import entry_points
 
 from .. import WebvizConfigTheme
 from ._default_theme import default_theme
 
-installed_themes = {  # pylint: disable=invalid-name
-    default_theme.theme_name: default_theme
-}
+installed_themes = {default_theme.theme_name: default_theme}
 
 __all__ = ["installed_themes"]
 
